pub enum Command {
AddNode {
addr: SocketAddr,
},
FindPeers {
info_hash: [u8; 20],
callback: Sender<SocketAddr>,
local_peer_port: u16,
},
Shutdown,
}Expand description
Command from the user to the DHT system.
Variants
AddNode
Attempt to connect to a new node and insert it into the routing table.
Fields

addr: SocketAddrFindPeers
Commence search for peers for the given torrent.
Fields

callback: Sender<SocketAddr>Channel for sending back addresses of the discovered peers.
Shutdown
Shut down the DHT system.